function [statisticData] = digestionSimulation( genomeData)

%the function returns a a record structure containing 
%statistics on resulting fragments when applying restriction enzymes to 
%the genome in imput. The enzymes investigated are all the one present in 
%the rebase database.

%get the list of all the enzyme in rebase
[name, pattern, len, ncuts,blunt,c1,c2,c3,c4] = readrebase;
%group together enzymes with the same pattern
%number of restriction enzymes
nRestEnzymes=length(name);
%index for the datastructure with statistic data
j=1;
thereAreDataInStructure=0;
%get the gene annotation information
geneInfo=extractGenesInfoFromGenomeAnnotation( genomeData );
%get the list of the essential genes
%genes consistently essential between Gerdes et al., 2002 and PEC 
load('essentialGenes.mat');
%for all restryction enzymes
for i=1:nRestEnzymes
  %eliminate enzymes 661 and 662 that causes a not yet identified errors
  %in the toolbox functions
  if ((i~=661)&&(i~=662))
    %check if the enzyme has a pattern already analyzed and in case group it
    isAlreadyAnalyzed=0;
    if (thereAreDataInStructure)
     for z=1:length(statisticData)
         if strcmp(upper(pattern{i}),upper(statisticData(z).Pattern))
           statisticData(z).Names= [statisticData(z).Names {name{i}}];
           isAlreadyAnalyzed=1;
         end   
     end    
    end
    if (~isAlreadyAnalyzed) 
     fprintf(1,'%d: Analysing enzyme %s.\n',i,name{i});
     %extract the data for the digestion with this enzyme
     atomKnockOutStruct=createAtomicKnockoutStruct(genomeData,geneInfo,name{i},pattern{i});
     fragments=atomKnockOutStruct.fragments;
     lengths=atomKnockOutStruct.lengths;
     nGenes=atomKnockOutStruct.nGenes;
     %calculate how many fragments contains at least one essential gene
     total=0;
     for g=1:length(atomKnockOutStruct.blattnerId)
         count=0;
         for p=1:length(atomKnockOutStruct.blattnerId{g})                 
             str=atomKnockOutStruct.blattnerId{g}{p};    
             array=essentialGenes';
             if (sum(strcmp(str,array)))
                 count=1;               
             end   
         end
         total=total+count;
     end    
     %save statistics line for this enzyme
     record.Names={name{i}};
     record.Pattern=pattern{i};
     record.NumberOfFragments=length(fragments);
     record.MeanLength=mean(lengths);
     record.VarLength=var(lengths);
     record.MeanGenes=mean(nGenes);
     record.VarGenes=var(nGenes);
     record.MaxFrag=max(nGenes);
     record.MinFrag=min(nGenes);
     record.PercEssentialGenes=total/record.NumberOfFragments;
     statisticData(j)=record;
     thereAreDataInStructure=1;
     j=j+1;
    end
  end 
end
%sort elements
[temp,indexes]=sort([statisticData.NumberOfFragments]);
statisticData=statisticData(indexes);
end



