function [] = genomeStaticAnalysis(statisticData)

%main module that performs digestion of E.Coli K12 MG1665 chromosome using
%all the restriction enzymes present in REBASE database, calculates
%statistics on the cutting patterns and creates the plots

%load genome information for E.Coli K12 MG1665
genomeData =getgenbank('AP009048');
%perform digestion of chromosome using all restriction enzymes
[statisticData] = digestionSimulation(genomeData);

%plot restriction enzyme group representative against number of fragments
h=figure;
%extract names of restriction enzymes for x axis
for resIndex=1:length(statisticData)
    %extract enzyme name
    resNames{resIndex}=statisticData(resIndex).Names{1};   
end
%get number of fragments
numberOfFragVector=[statisticData.NumberOfFragments];

%prinf of the first plot
%plot number of fragments
l=plot(1:length(numberOfFragVector),numberOfFragVector,'*r');
%limit axes
xlim([0 270]);
%set restriction enzyme names as XTickLables
set(gca,'XTick',1:5:length(numberOfFragVector),'FontSize'   , 11    );
set(gca,'XTickLabel',resNames(1:5:length(numberOfFragVector)),'FontSize'   , 11    );
set(l                         , ...
  'Marker'          , 'o'        , ...
  'MarkerSize'      , 5           , ...
  'MarkerEdgeColor' , 'none'      , ...
  'MarkerFaceColor' , [1 0 0] );
%set labels and text
hTitle=title('Restriction enzyme ordered depending on the number of fragments generate after digestion of E.Coli K12 chromosome');
hYLabel=ylabel('Number of fragments after digestion');
set( hTitle                    , ...
    'FontSize'   , 12          , ...
    'FontWeight' , 'bold'      );
set([ hYLabel]  , ...
    'FontSize'   , 11          );
%ticks rotated
rot = 50;
%get current tick labels
a=get(gca,'XTickLabel');
%erase current tick labels from figure
set(gca,'XTickLabel',[]);
%get tick label positions
b=get(gca,'XTick');
c=get(gca,'YTick');
%make new tick labels
if rot<180
        th=text(b,repmat(c(1)-.1*(c(2)-c(1)),length(b),1),a,'HorizontalAlignment','right','rotation',rot,'FontSize'   , 11);
else
        th=text(b,repmat(c(1)-.1*(c(2)-c(1)),length(b),1),a,'HorizontalAlignment','left','rotation',rot,'FontSize'   , 11);
end

%print of the second plot
h=figure;
%get number of gene per fragment
meanGenesVector=[statisticData.MeanGenes];
%
l=loglog(numberOfFragVector,meanGenesVector,'*r');
set(l                         , ...
  'Marker'          , 'o'        , ...
  'MarkerSize'      , 5           , ...
  'MarkerEdgeColor' , 'none'      , ...
  'MarkerFaceColor' , [1 0 0] );
%set labels and text
hTitle=title('Relation between number of fragments and mean number of genes per fragment');
hXLabel=Xlabel('Number of fragments');
hYLabel=ylabel('Mean number of gene per fragment');
set( hTitle                    , ...
    'FontSize'   , 12          , ...
    'FontWeight' , 'bold'      );
set([ hYLabel]  , ...
    'FontSize'   , 11          );

%print of the third plot
h=figure;
%get the variance of gene per fragment
varGenesVector=[statisticData.VarGenes];
%
l=loglog(numberOfFragVector,varGenesVector,'*r');
set(l                         , ...
  'Marker'          , 'o'        , ...
  'MarkerSize'      , 5           , ...
  'MarkerEdgeColor' , 'none'      , ...
  'MarkerFaceColor' , [1 0 0] );
%set labels and text
hTitle=title('Relation between number of fragments and variance from the number of mean genes per fragment');
hXLabel=Xlabel('Number of fragments');
hYLabel=ylabel('Variance in number of gene per fragment');
set( hTitle                    , ...
    'FontSize'   , 12          , ...
    'FontWeight' , 'bold'      );
set([ hYLabel]  , ...
    'FontSize'   , 11          );

%print of the fourth plot
h=figure;
%get the variance of gene per fragment
essenGenesVector=[statisticData.PercEssentialGenes]*100;
%
l=loglog(numberOfFragVector,essenGenesVector,'*r');
set(l                         , ...
  'Marker'          , 'o'        , ...
  'MarkerSize'      , 5           , ...
  'MarkerEdgeColor' , 'none'      , ...
  'MarkerFaceColor' , [1 0 0] );
%set labels and text
hTitle=title('Relation between number of fragments and probability of having an essential gene per fragment');
hXLabel=Xlabel('Number of fragments');
hYLabel=ylabel('Probability of having an essential gene per fragment ');
set( hTitle                    , ...
    'FontSize'   , 12          , ...
    'FontWeight' , 'bold'      );
set([ hYLabel]  , ...
    'FontSize'   , 11          );

%print of the fifth plot
h=figure;
%get the variance of gene per fragment
varLengthVector=[statisticData.VarLength];
VarGenesLength=[statisticData.VarGenes];
%plot
l=loglog(varLengthVector,VarGenesLength,'*r');
set(l                         , ...
  'Marker'          , 'o'        , ...
  'MarkerSize'      , 5           , ...
  'MarkerEdgeColor' , 'none'      , ...
  'MarkerFaceColor' , [1 0 0] );
%set labels and text
hTitle=title('Relation between variance in fragment size and variance in gene per fragment');
hXLabel=Xlabel('Variance of fragment size');
hYLabel=ylabel('Variance of gene per fragment');
set( hTitle                    , ...
    'FontSize'   , 12          , ...
    'FontWeight' , 'bold'      );
set([ hYLabel]  , ...
    'FontSize'   , 11          );
end


